@@ -9,6 +9,8 @@
 # Modifications: 
 #		20111210, cjgb: in the data string, "-" may represent the value 0
 #		20111210, cjgb: fixing the strsplit when the split character is contained in the data part
+#		20120329, cjgb: number strings in the DATA part can contain ";" as separators.
+#				Although deprecated, cases still lurk.
 #
 #################################################################
 
@@ -54,6 +56,11 @@ read.px <- function(filename, encoding = "latin1",
 
     a <- scan(filename, what = "character", sep = "\n", quiet = TRUE, fileEncoding = encoding)
     a <- paste(a, collapse = " ")	## " " necesario para que no junte lineas en DATA
+
+    tmp <- strsplit( a, "DATA=" )[[1]]
+    tmp[2] <- gsub(";", "", tmp[2])			# removing ";" within DATA number strings
+    a <- paste(tmp[1], "DATA=", tmp[2], sep = "")
+
     a <- unlist(strsplit(a, ";"))	## ; is the logical line end in px files
    
     a <- sub( "=", "//=//", a )
